package frc.robot.utilities;

import edu.wpi.first.util.sendable.SendableBuilder;

public class PIDFFValues extends PIDValues {
    private double s;
    private double g;
    private double v;
    private double a;

    public PIDFFValues(double p, double tolerance, double s, double v) {
        this(p, 0, tolerance, s, v);
    }

    public PIDFFValues(double p, double d, double tolerance, double s, double v) {
        this(p, 0, d, tolerance, s, v);
    }

    public PIDFFValues(double p, double i, double d, double tolerance, double s, double v) {
        this(p, i, d, tolerance, s, v, 0);
    }

    public PIDFFValues(double p, double i, double d, double tolerance, double s, double v, double a) {
        this(p, i, d, tolerance, s, 0, v, a);
    }

    public PIDFFValues(double p, double i, double d, double tolerance, double s, double g, double v, double a) {
        super(p, i, d, tolerance);

        this.s = s;
        this.g = g;
        this.v = v;
        this.a = a;
    }

    public double getS() {
        return s;
    }

    public double getG() {
        return g;
    }

    public double getV() {
        return v;
    }

    public double getA() {
        return a;
    }

    public void setS(double s) {
        this.s = s;
    }

    public void setG(double g) {
        this.g = g;
    }

    public void setV(double v) {
        this.v = v;
    }

    public void setA(double a) {
        this.a = a;
    }

    @Override
    public void initSendable(SendableBuilder builder) {
        super.initSendable(builder);

        builder.addDoubleProperty("S", this::getS, this::setS);
        builder.addDoubleProperty("G", this::getG, this::setG);
        builder.addDoubleProperty("V", this::getV, this::setV);
        builder.addDoubleProperty("A", this::getA, this::setA);
    }
}
